@@ -124,7 +124,11 @@ models_inference   <- function(model_list){
   prior_weights  <- sapply(model_list, function(model)model[["prior_weights"]])
   prior_probs <- prior_weights / sum(prior_weights)
   post_probs  <- unname(bridgesampling::post_prob(margliks, prior_prob = prior_probs))
-  incl_BF     <- sapply(seq_along(model_list), function(i) (post_probs[i] / (1 - post_probs[i])) / (prior_probs[i] / (1 - prior_probs[i])))
+  incl_BF     <- sapply(seq_along(model_list), function(i){
+    is_null <- rep(TRUE, length(model_list))
+    is_null[i] <- FALSE
+    return(inclusion_BF(prior_probs, post_probs, is_null))
+  })
 
   for(i in seq_along(model_list)){
     model_list[[i]][["inference"]] <- list(
@@ -272,6 +276,8 @@ mix_posteriors <- function(model_list, parameters, is_null_list, conditional = F
         colnames(model_samples) <- fits[[i]]$monitor
       }
     }else if(inherits(fits[[i]], "rstan")){
+      if(!try(requireNamespace("rstan")))
+        stop("rstan package needs to be installed. Run 'install.packages('rstan')'")
       model_samples <- rstan::extract(fits[[i]])
       par_names     <- names(model_samples)
       par_dims      <- sapply(model_samples, function(s)if(is.matrix(s)) ncol(s) else 1)
@@ -355,6 +361,8 @@ mix_posteriors <- function(model_list, parameters, is_null_list, conditional = F
         colnames(model_samples) <- fits[[i]]$monitor
       }
     }else if(inherits(fits[[i]], "rstan")){
+      if(!try(requireNamespace("rstan")))
+        stop("rstan package needs to be installed. Run 'install.packages('rstan')'")
       model_samples <- rstan::extract(fits[[i]])
       par_names     <- names(model_samples)
       par_dims      <- sapply(model_samples, function(s)if(is.matrix(s)) ncol(s) else 1)
